@@ -1,10 +1,10 @@
-// Gmsh - Copyright (C) 1997-2019 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2020 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
 // issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
 
-#ifndef _TREE_UTILS_H_
-#define _TREE_UTILS_H_
+#ifndef TREE_UTILS_H
+#define TREE_UTILS_H
 
 #include "avl.h"
 #include "ListUtils.h"
