@@ -40,79 +40,6 @@ discreteEdge::discreteEdge(GModel *model) : GEdge(model, 0)
   // the corresponding entity in GEO internals
 }
 
-bool discreteEdge::_orderMLines(bool isCompound)
-{
-  std::size_t ss = lines.size();
-  if(!ss) return true;
-
-  std::vector<MEdge> ed;
-  std::vector<std::vector<MVertex *> > vs;
-  for(std::size_t i = 0; i < lines.size(); i++) {
-    ed.push_back(MEdge(lines[i]->getVertex(0), lines[i]->getVertex(1)));
-    delete lines[i];
-  }
-  lines.clear();
-
-  if(!SortEdgeConsecutive(ed, vs))
-    Msg::Warning("Discrete curve elements cannot be ordered");
-
-  if(vs.size() != 1)
-    Msg::Warning("Discrete curve %d is mutiply connected", tag());
-
-  std::size_t START = 0;
-  for(; START < vs[0].size(); START++)
-    if(vs[0][START]->onWhat()->dim() == 0) break;
-
-  if(START == vs[0].size())
-    Msg::Warning("Discrete curve %d topology is wrong", tag());
-
-  std::size_t i = START;
-  while(lines.size() != ss) {
-    if(vs[0][i % vs[0].size()] != vs[0][(i + 1) % vs[0].size()])
-      lines.push_back(
-        new MLine(vs[0][i % vs[0].size()], vs[0][(i + 1) % vs[0].size()]));
-    i++;
-  }
-
-  mesh_vertices.clear();
-  for(std::size_t i = 0; i < lines.size() - 1; ++i) {
-    MVertex *v11 = lines[i]->getVertex(1);
-    if(v11->onWhat() == this || !v11->onWhat()){
-      v11->setEntity(this);
-      mesh_vertices.push_back(v11);
-    }
-    else if(!isCompound){
-      // no error for compound, where the mesh_vertices are just pointing to the
-      // original ones on their respective entities, and the vector will be
-      // cleared without deleting its contents as soon as createGeometry is done
-      Msg::Error("Discrete curve %d topology is wrong (node %lu classified "
-                 "on %s %d)", tag(), v11->getNum(),
-                 (v11->onWhat()->dim() == 3) ? "volume" :
-                 (v11->onWhat()->dim() == 2) ? "surface" :
-                 (v11->onWhat()->dim() == 1) ? "curve" : "point",
-                 v11->onWhat()->tag());
-    }
-  }
-
-  deleteVertexArrays();
-  model()->destroyMeshCaches();
-
-  if(lines.empty()) {
-    Msg::Error("No line elements in discrete curve %d", tag());
-    return false;
-  }
-  GVertex *g0 = dynamic_cast<GVertex *>(lines[0]->getVertex(0)->onWhat());
-  if(g0) setBeginVertex(g0);
-  GVertex *g1 =
-    dynamic_cast<GVertex *>(lines[lines.size() - 1]->getVertex(1)->onWhat());
-  if(g1) setEndVertex(g1);
-  if(!g0 || !g1){
-    Msg::Error("Discrete curve %d has non consecutive line elements", tag());
-    return false;
-  }
-  return true;
-}
-
 bool discreteEdge::_getLocalParameter(const double &t, int &iLine,
                                      double &tLoc) const
 {
@@ -251,63 +178,39 @@ Range<double> discreteEdge::parBounds(int i) const
   return Range<double>(0, (double)(_discretization.size() - 1));
 }
 
-int discreteEdge::createGeometry(bool isCompound)
+int discreteEdge::createGeometry()
 {
   if(lines.empty()) return 0;
 
   if(!_discretization.empty()) return 0;
 
-  // FIXME: createGeometry should *not* modify the mesh (and should thus not
-  // call _orderMLines) - it should assume that the mesh is already correctly
-  // ordered. Any reordering should be made explicitely before.
+  GVertex *g0 = dynamic_cast<GVertex *>
+    (lines[0]->getVertex(0)->onWhat());
+  if(g0) setBeginVertex(g0);
 
-  if(!_orderMLines(isCompound))
-    return -1;
+  GVertex *g1 = dynamic_cast<GVertex *>
+    (lines[lines.size() - 1]->getVertex(1)->onWhat());
+  if(g1) setEndVertex(g1);
 
-  bool reverse = false;
-  if(getEndVertex())
-    reverse = (lines[0]->getVertex(0) == getEndVertex()->mesh_vertices[0]);
-
-  std::map<MVertex *, MVertex *> old2new;
+  if(!g0 || !g1){
+    Msg::Error("Discrete curve %d has no begin or end point", tag());
+    return 1;
+  }
 
+  _discretization.push_back(SPoint3(lines[0]->getVertex(0)->x(),
+                                    lines[0]->getVertex(0)->y(),
+                                    lines[0]->getVertex(0)->z()));
   for(std::size_t i = 0; i < lines.size(); i++) {
-    for(std::size_t j = 0; j < 2; j++) {
-      MVertex *v = lines[i]->getVertex(j);
-      if(old2new.find(v) == old2new.end()) {
-        MVertex *vnew = new MVertex(v->x(), v->y(), v->z(), this);
-        old2new[v] = vnew;
-      }
-    }
+    _discretization.push_back(SPoint3(lines[i]->getVertex(1)->x(),
+                                      lines[i]->getVertex(1)->y(),
+                                      lines[i]->getVertex(1)->z()));
   }
 
-  std::vector<MLine *> discrete_lines(lines.size());
-  for(std::size_t i = 0; i < lines.size(); i++) {
-    MVertex *v0 = lines[i]->getVertex(0);
-    MVertex *v1 = lines[i]->getVertex(1);
-    MVertex *v00 = old2new[v0];
-    MVertex *v01 = old2new[v1];
-    if(reverse)
-      discrete_lines[lines.size() - i - 1] = new MLine(v01, v00);
-    else
-      discrete_lines[i] = new MLine(v00, v01);
-  }
-  _discretization.push_back(SPoint3(discrete_lines[0]->getVertex(0)->x(),
-                                    discrete_lines[0]->getVertex(0)->y(),
-                                    discrete_lines[0]->getVertex(0)->z()));
-
-  for(std::size_t i = 0; i < discrete_lines.size(); i++) {
-    _discretization.push_back(SPoint3(discrete_lines[i]->getVertex(1)->x(),
-                                      discrete_lines[i]->getVertex(1)->y(),
-                                      discrete_lines[i]->getVertex(1)->z()));
-  }
-  for(std::size_t i = 0; i < discrete_lines.size(); i++)
-    delete discrete_lines[i];
-
   _pars.push_back(0.0);
-  for(std::size_t i = 1; i < discrete_lines.size(); i++) {
+  for(std::size_t i = 1; i < lines.size(); i++) {
     _pars.push_back((double)i);
   }
-  _pars.push_back((double)discrete_lines.size());
+  _pars.push_back((double)lines.size());
 
   return 0;
 }
