@@ -1,10 +1,10 @@
-// Gmsh - Copyright (C) 1997-2018 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2020 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// issues on https://gitlab.onelab.info/gmsh/gmsh/issues
+// issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
 
-#ifndef _QUALITY_MEASURES_H_
-#define _QUALITY_MEASURES_H_
+#ifndef QUALITY_MEASURES_H
+#define QUALITY_MEASURES_H
 
 //#include "fullMatrix.h"
 #include <vector>
