@@ -713,7 +713,8 @@ cpp_header="""// {0}
 // Do not edit it directly: it is automatically generated by `api/gen.py'.
 //
 // By design, the {3} C++ API is purely functional, and only uses elementary
-// types from the standard library. See `demos/api' for examples.
+// types from the standard library. See `tutorial/c++' and `demos/api' for
+// examples.
 
 #if defined(_MSC_VER) && !defined(_USE_MATH_DEFINES)
 #define _USE_MATH_DEFINES
@@ -770,7 +771,7 @@ c_header="""/*
  * Do not edit it directly: it is automatically generated by `api/gen.py'.
  *
  * By design, the {3} C API is purely functional, and only uses elementary
- * types. See `demos/api' for examples.
+ * types. See `tutorial/c' and `demos/api' for examples.
  */
 
 #include <stddef.h>
@@ -936,8 +937,8 @@ python_header = """# {0}
 # Do not edit it directly: it is automatically generated by `api/gen.py'.
 #
 # By design, the {2} Python API is purely functional, and only uses elementary
-# types (as well as `numpy' arrays if `numpy' is avaiable). See `demos/api' for
-# examples.
+# types (as well as `numpy' arrays if `numpy' is avaiable). See
+# `tutorial/python' and `demos/api' for examples.
 
 from ctypes import *
 from ctypes.util import find_library
@@ -1121,7 +1122,7 @@ julia_header = """# {0}
 # Do not edit it directly: it is automatically generated by `api/gen.py'.
 #
 # By design, the {2} Julia API is purely functional, and only uses elementary
-# types. See `demos/api' for examples.
+# types. See `tutorial/julia' and `demos/api' for examples.
 """
 
 def capi(s): return s[:1].upper() + s[1:]
